setMethod("show", "intactInteraction", function(object)
        cat("interaction (", object@intact, "):\n",
                "---------------------------------\n",
                "[ interaction type ]:", object@interactionType, "\n",
                "[ experiment ]: pubmed ", object@expPubMed, ", intact ", object@expIntAct, "\n",
		"[ confidence value ]: ", object@confidenceValue, "\n",
                "[ bait ]: ", object@bait, "\n",
                "[ prey ]: ", object@prey, "\n",
		"[ neutral component ]: ", object@neutralComponent, "\n",
                "[ inhibitor ]: ", object@inhibitor, "\n")
)

setMethod("show", "interactionEntry", function(object) {
        cat("==================================\n",
                "interaction entry (", object@releaseDate, "):\n",
                "==================================\n",
                "[ organism ]: ", object@organismName, "\n",
                "[ taxonomy ID ]: ", object@taxId, "\n",
                "[ interactors ]: there are ", nrow(object@interactors), 
		" interactors in total, here are the first few ones:\n")
        print(utils::head(object@interactors))
        cat("...\n", "[ interactions ]: there are ", 
		length(object@interactions), " interactions in total, here are the first few ones:\n")
        print(utils::head(object@interactions))
        cat("...\n")
	cat("Please use 'interactors' to view all interactors, and 'interactions' to view all interactions.\n")
})

setMethod("show", "intactComplex", function(object) {
        cat("complex (", object@intactId, ")\n",
                "---------------------------------\n",
		"[ short label ]: ", object@shortLabel, "\n",
                "[ full name ]: ", object@fullName, "\n",
                "[ organism ]: ", object@organismName, "\n",
                "[ taxonomy ID ]: ", object@taxId, "\n",
                "[ attributes ]: \n")
        b = object@attributes
        for(i in seq(along=b))
          cat(strbreak(paste(names(b)[i], b[i], sep=": ")), "\n")
        cat(" [ members ]: \n")
        print(object@members)
})

setMethod("show", "complexEntry", function(object) {
        cat("==================================\n",
                "complex entries (", object@releaseDate, "):\n",
                "==================================\n",
                "[ interactors ]: there are ", nrow(object@interactors), 
		"interactors in total, here are the first few ones:\n")
        print(utils::head(object@interactors))
        cat("...\n", "[ complexes ]: there are ", length(object@complexes), 
		"complexes in total, here are the first few ones:\n")
        print(utils::head(object@complexes))
        cat("...\n")
	cat("Please use 'interactors' to view all interactors, and use 'complexes' to view all complexes.\n")
})

setMethod("show", "intactGraph", function(object){
  print(class(object))
  })

setMethod("show", "intactHyperGraph", function(object){
  print(class(object))
  })

setMethod("translateIntactID", signature(r="intactGraph"),
          function(r, ebiNames, toWhat){
            return(r@interactors[ebiNames, toWhat, drop=FALSE])
          })

setMethod("translateIntactID", signature(r="intactHyperGraph"),
          function(r, ebiNames, toWhat){
            return(r@interactors[ebiNames, toWhat, drop=FALSE])
          })

setMethod("initialize",
          signature=signature(
            .Object="intactHyperGraph"),
          function(.Object, interactors, ...) {
            .Object@interactors <- interactors
            callNextMethod(.Object, ...)
          })


###

setMethod("interactors", signature(x="interactionEntry"),
          function(x) x@interactors)
setMethod("interactors", signature(x="complexEntry"),
          function(x) x@interactors)
setMethod("interactions", signature(x="interactionEntry"),
          function(x) x@interactions)
setMethod("complexes", signature(x="complexEntry"),
          function(x) x@complexes)
setMethod("bait", signature(x="intactInteraction"),
          function(x) x@bait)
setMethod("prey", signature(x="intactInteraction"),
          function(x) x@prey)
setMethod("organismName", signature(x="interactionEntry"),
          function(x) x@organismName)
setMethod("taxId", signature(x="interactionEntry"),
          function(x) x@taxId)
setMethod("releaseDate", signature(x="interactionEntry"),
          function(x) x@releaseDate)

setMethod("translateNodeID", signature(g="intactGraph"),
          function(g,newID="locusName"){
            map2locusM = translateIntactID(g,ebiNames=nodes(g),toWhat=newID)
            map2locus = as.vector(map2locusM)
            names(map2locus) = rownames(map2locusM)
            
            naVals = which(is.na(map2locus))
            map2locus[naVals] = names(map2locus)[naVals]
            
            nodes(g) = unname(map2locus[nodes(g)])
            g
          })
