\name{interactionEntry-class}
\docType{class}
\alias{interactionEntry-class}
\alias{show,interactionEntry-method}
\alias{bait,interactionEntry-method}
\alias{prey,interactionEntry-method}
\alias{interactions,interactionEntry-method}
\alias{interactors,interactionEntry-method}
\alias{organismName,interactionEntry-method}
\alias{taxId,interactionEntry-method}
\alias{releaseDate,interactionEntry-method}

\title{Class "interactionEntry"}
\description{
A class representing the interaction data extracted from an IntAct data file
in PSI-MI 2.5 format.}
\section{Objects from the Class}{
 Objects are usually created by \code{psi25interaction}.
}
\section{Slots}{
 \describe{
   \item{\code{releaseDate}:}{character, release date of the data entry, 
	recorded in the \code{entry} element of the XML file.}
   \item{\code{organismName}:}{character, the unique organism name(s) of
	the interactors.}
   \item{\code{taxId}:}{character, the unique NCBI taxonomy ID(s) of
	the interactors.}
   \item{\code{interactors}:}{matrix, Each row represents one interactor. IntAct
	IDs are used as row names. Each column represents one annotation. 
	Annotations include: UniProt ID, gene symbol, full name, locus name, ORF name,
        organism name, and NCBI taxonomy ID.}
   \item{\code{interactiones}:}{list, a list of \code{intactInteraction} objects, 
	each represents one interaction.} 
 }
}
\section{Methods}{
 \describe{
   \item{show}{\code{signature(object = "interactionEntry")}: a print method}
\item{bait}{\code{signature(object = "interactionEntry")}: a method to find all the
baits within the interactionEntry and print them}
\item{prey}{\code{signature(object = "interactionEntry")}: a method to find all the 
prey within the interactionEntry and print them}
\item{interactions}{\code{signature(object = "interactionEntry")}: a method to find
all the interactions within the interactionEntry and print them}
\item{interactors}{\code{signature(object = "interactionEntry")}: a method to find 
all the interactors within the interactionEntry and print them}

\item{organismName}{\code{signature(object = "interactionEntry")}: a method to print
all the unique organism names that are of the interactors} 
\item{taxId}{\code{signature(object = "interactionEntry")}: a method to print
each taxonomy id for each organism}
\item{releaseDate}{\code{signature(object = "interactionEntry")}: a method to print 
the updated release date of the PSI-MI 2.5 XML file; it serves as a proxy for versioning.}
 }
}
\references{The IntAct Database: \url{http://www.ebi.ac.uk/intact/site/contents/downloads.jsf}.}

\author{Nianhua Li}

\seealso{\code{\link{intactInteraction-class}}, \code{\link{psi25interaction}}}

\keyword{models}
